@@ -317,6 +317,16 @@ class EdgeStorage:
         """Returns all population names inside this file."""
         return self.storage.population_names
 
+    @property
+    def h5_filepath(self):
+        """Returns the filepath of the Storage."""
+        return self._h5_filepath
+
+    @property
+    def csv_filepath(self):
+        """Returns the csv filepath of the Storage."""
+        return self._csv_filepath
+
     @property
     def circuit(self):
         """Returns the circuit object containing this storage."""
