@@ -170,6 +170,16 @@ class NodeStorage:
         """Returns all population names inside this file."""
         return self.storage.population_names
 
+    @property
+    def h5_filepath(self):
+        """Returns the filepath of the Storage."""
+        return self._h5_filepath
+
+    @property
+    def csv_filepath(self):
+        """Returns the csv filepath of the Storage."""
+        return self._csv_filepath
+
     @property
     def circuit(self):
         """Returns the circuit object containing this storage."""
@@ -623,7 +633,7 @@ class NodePopulation:
             return result.get(prop, np.zeros((result.shape[0],)))
 
         args = [_get_values(prop) for prop in props]
-        if isinstance(group, (int, np.integer, CircuitNodeId)):
+        if utils.is_node_id(group):
             return trans(*args)[0]
         return pd.Series(trans(*args), index=result.index, name='orientation')
 
