@@ -25,6 +25,7 @@ import numpy as np
 from libsonata import SpikeReader, SonataError
 
 from bluepysnap.exceptions import BluepySnapError
+from bluepysnap.utils import IDS_DTYPE
 import bluepysnap._plotting
 
 
@@ -38,7 +39,7 @@ def _collect_spikes(spike_report):
             spike_report.population_names}
 
 
-class PopulationSpikeReport(object):
+class PopulationSpikeReport:
     """Access to PopulationSpikeReport data."""
 
     def __init__(self, spike_report, population_name):
@@ -110,7 +111,7 @@ class PopulationSpikeReport(object):
         res = pd.DataFrame(data=res, columns=[series_name, "times"]).set_index("times")[series_name]
         if self._sorted_by != "by_time":
             res.sort_index(inplace=True)
-        return res.astype(np.int64)
+        return res.astype(IDS_DTYPE)
 
     @cached_property
     def node_ids(self):
@@ -122,7 +123,7 @@ class PopulationSpikeReport(object):
         return np.unique(self.get())
 
 
-class FilteredSpikeReport(object):
+class FilteredSpikeReport:
     """Access to filtered SpikeReport data."""
 
     def __init__(self, spike_report, group=None, t_start=None, t_stop=None):
@@ -174,7 +175,7 @@ class FilteredSpikeReport(object):
     firing_animation = bluepysnap._plotting.spikes_firing_animation
 
 
-class SpikeReport(object):
+class SpikeReport:
     """Access to SpikeReport data."""
 
     def __init__(self, simulation):
